==> haskell-hspec-wai-json-0.11.0-689-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-wai-json
version:              0.11.0
visibility:           public
id:                   hspec-wai-json-0.11.0-1YmBGMFM3RiAhjiCbCIkK6
key:                  hspec-wai-json-0.11.0-1YmBGMFM3RiAhjiCbCIkK6
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Testing JSON APIs with hspec-wai
description:          Testing JSON APIs with hspec-wai
category:             Testing
abi:                  e1abf468150e64fabe946b420182b540
exposed:              True
exposed-modules:      Test.Hspec.Wai.JSON
hidden-modules:       Paths_hspec_wai_json
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai-json
hs-libraries:         HShspec-wai-json-0.11.0-1YmBGMFM3RiAhjiCbCIkK6
depends:
    aeson-2.1.2.1-6h5MFvBT17H5yplsTy4ABm
    aeson-qq-0.8.4-IlA3klcOtOq2w7evkCxn4l base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-rTys5srD4l50KQCiQKWYt
    hspec-wai-0.11.1-4sbunx3MrifHVy2sHh0pK5 template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock

haddock-html:         /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-json-0.11.0-690-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-wai-json
version:              0.11.0
visibility:           public
id:                   hspec-wai-json-0.11.0-FwaghsbiPTbKvLixTJaFbk
key:                  hspec-wai-json-0.11.0-FwaghsbiPTbKvLixTJaFbk
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Testing JSON APIs with hspec-wai
description:          Testing JSON APIs with hspec-wai
category:             Testing
abi:                  5beac4ac3eb253b76d83912cd654696e
exposed:              True
exposed-modules:      Test.Hspec.Wai.JSON
hidden-modules:       Paths_hspec_wai_json
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai-json
hs-libraries:         HShspec-wai-json-0.11.0-FwaghsbiPTbKvLixTJaFbk
depends:
    aeson-2.1.2.1-9rGsBPhyshTKvPzkopJx8r
    aeson-qq-0.8.4-N8gmA59P4QE4rZa0DnCIX base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-4HYxnyEi2mnBK2ectdARDN
    hspec-wai-0.11.1-8eF7D2P1F4OyV6WMAMT2V template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock

haddock-html:         /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
